@@ -1,21 +1,7 @@
-/********************************************************************
-Copyright 2016  Eike Hein <hein.org>
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the
-Free Software Foundation, Inc.,
-51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .
-*********************************************************************/
+/*
+    SPDX-FileCopyrightText: 2016 Eike Hein <hein.org>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef PAGERMODEL_H
 #define PAGERMODEL_H
@@ -99,8 +85,13 @@ public:
 
     Q_INVOKABLE void refresh();
 
-    Q_INVOKABLE void
-    moveWindow(const QVariant &window, double x, double y, const QVariant &targetItemId, const QVariant &sourceItemId, qreal widthScaleFactor, qreal heightScaleFactor);
+    Q_INVOKABLE void moveWindow(const QModelIndex &window,
+                                double x,
+                                double y,
+                                const QVariant &targetItemId,
+                                const QVariant &sourceItemId,
+                                qreal widthScaleFactor,
+                                qreal heightScaleFactor);
     Q_INVOKABLE void changePage(int page);
     Q_INVOKABLE void drop(QMimeData *mimeData, int modifiers, const QVariant &itemId);
     Q_INVOKABLE void addDesktop();
