@@ -25,7 +25,7 @@
 
 #include "timedated_interface.h"
 
-K_PLUGIN_FACTORY(KlockModuleFactory, registerPlugin<KclockModule>();)
+K_PLUGIN_CLASS_WITH_JSON(KclockModule, "clock.json")
 
 KclockModule::KclockModule(QWidget *parent, const QVariantList &)
     : KCModule(parent)
@@ -59,7 +59,6 @@ KclockModule::KclockModule(QWidget *parent, const QVariantList &)
 
     QVBoxLayout *layout = new QVBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
-    layout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
 
     dtime = new Dtime(this, m_haveTimedated);
     layout->addWidget(dtime);
